PdfMargins class

Constructors

PdfMargins({num top = 0, num bottom = 0, num left = 0, num right = 0})
PdfMargins.cm({num top = 0, num bottom = 0, num left = 0, num right = 0})
PdfMargins.cm then return in Inches
factory
PdfMargins.inches({num? top, num? bottom, num? left, num? right})
PdfMargins.mm({num top = 0, num bottom = 0, num left = 0, num right = 0})
PdfMargins.mm then return in Inches
factory
PdfMargins.px({int top = 0, int bottom = 0, int left = 0, int right = 0})
PdfMargins.px then return in Inches
factory

Properties

bottom ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
left ↔ num
getter/setter pair
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, num>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

zero → PdfMargins
final