BrowserPlatform enum

Inheritance
Available extensions

Values

macArm64 → const BrowserPlatform
const BrowserPlatform._('macos_arm64', 'mac-arm64')
macX64 → const BrowserPlatform
const BrowserPlatform._('macos_x64', 'mac-x64')
linux64 → const BrowserPlatform
const BrowserPlatform._('linux_x64', 'linux64')
windows32 → const BrowserPlatform
const BrowserPlatform._('windows_ia32', 'win32')
windows64 → const BrowserPlatform
const BrowserPlatform._('windows_x64', 'win64')

Properties

dartPlatform → String
final
folder → String
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

current → BrowserPlatform
final

Static Methods

fromString(String platformString) → BrowserPlatform

Constants

values → const List<BrowserPlatform>
A constant List of the values in this enum, in order of their declaration.