ChromeDesktopDirectoryHelper class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

applicationSupportPath() FutureOr<String>
assetChromeZipPath() String?
ensureChromeExecutable({String? assetPath = null}) FutureOr<String>
getChromeExecutableOrExtract({String? assetPath, bool forceReextract = false}) FutureOr<String>
getChromeExecutablePath() FutureOr<String>
getOrCreateChromeExecutable({String? assetPath = null}) FutureOr<String>
saveChromeFromAssetToApp({String? assetPath = null}) FutureOr<String>
simpleUnzip(String path, String targetPath) FutureOr<void>
unzip(String path, String targetPath) FutureOr<void>
zipFileName() FutureOr<String>

Constants

appsDirPath → const String